@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-29 11:00:52
-:LastEditTime: 2021-07-02 14:31:38
-:LastEditors: HuangJingCan
+:LastEditTime: 2022-01-18 19:08:27
+:LastEditors: ChenXiaolei
 :Description: 文件上传信息
 """
 from PIL import Image
@@ -12,6 +12,7 @@ from seven_studio.libs.file.ks3 import *
 from seven_studio.libs.file.oss2 import *
 from seven_studio.libs.file.cos import *
 from seven_studio.libs.file.bos import *
+from seven_studio.libs.file.s3 import *
 from seven_studio.utils.random import *
 from seven_framework.time import *
 from seven_framework.uuid import *
@@ -192,6 +193,9 @@ class FileUpload():
             elif file_storage_path.StorageTypeID == 7:
                 # 百度云
                 invoke_result = BOS.upload(file_storage_path.StorageConfig, file_name, stream)
+            elif file_storage_path.StorageTypeID == 8:
+                # AWS
+                invoke_result = S3.upload(file_storage_path.StorageConfig, file_name, stream)
 
             if invoke_result.ResultCode != "0":
                 return invoke_result
